==> qtjambi-debuginfo-macos-5.15.19.jar: sources/QtJambiCore/QEasingCurve_EasingFunction_shell.cpp <==
#include "QEasingCurve_EasingFunction_shell.h"
#include <QtJambi/RegistryAPI>
#include <QtJambi/FunctionPointer>
#include <QtJambi/Cast>

#if QT_CONFIG(easingcurve)

// emitting (writeShellConstructor)
void deleter_QEasingCurve_EasingFunction(void *ptr,bool) { delete reinterpret_cast<QEasingCurve_EasingFunction_shell*>(ptr); }


QEasingCurve_EasingFunction_shell::QEasingCurve_EasingFunction_shell()
    : FunctionalBase()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QEasingCurve_EasingFunction_shell::QEasingCurve_EasingFunction_shell()")
    QEasingCurve_EasingFunction_shell::__shell()->constructed(typeid(QEasingCurve::EasingFunction));
}

// emitting (writeShellDestructor)
QEasingCurve_EasingFunction_shell::~QEasingCurve_EasingFunction_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QEasingCurve_EasingFunction_shell::~QEasingCurve_EasingFunction_shell()", QEasingCurve_EasingFunction_shell::__shell())
    if(m_functionPointerDeleter)
        m_functionPointerDeleter();
    QEasingCurve_EasingFunction_shell::__shell()->destructed(typeid(QEasingCurve::EasingFunction));
}

// construct QEasingCurve_EasingFunction_shell
void __qt_construct_QEasingCurve_EasingFunction(void* __qtjambi_ptr, JNIEnv*, jobject, jvalue*, bool)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QEasingCurve::EasingFunction")
    new (__qtjambi_ptr) QEasingCurve_EasingFunction_shell();
}
// destruct QEasingCurve_EasingFunction_shell
void __qt_destruct_QEasingCurve_EasingFunction(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QEasingCurve::EasingFunction")
    reinterpret_cast<QEasingCurve_EasingFunction_shell*>(ptr)->~QEasingCurve_EasingFunction_shell();
}

void QEasingCurve_EasingFunction_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QEasingCurve_EasingFunction_shell*>(ptr)->QEasingCurve_EasingFunction_shell::__shell()->tryDeleteShell(typeid(QEasingCurve::EasingFunction));
}

QtJambiShell* QEasingCurve_EasingFunction_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QEasingCurve_EasingFunction_shell) ); }

QEasingCurve_EasingFunction_shell::Functor::Functor(QEasingCurve_EasingFunction_shell& functional) : FunctorBase(typeid(QEasingCurve::EasingFunction), functional) {}

QEasingCurve_EasingFunction_shell::Functor::Functor(const Functor& functor) : FunctorBase(functor) {}

QEasingCurve_EasingFunction_shell::Functor::~Functor() {}

qreal  QEasingCurve_EasingFunction_shell::Functor::operator()(qreal progress0)
{
    qreal __qt_return_value = 0.0;
    if (jmethodID method_id = javaMethod()) {
        if (JniEnvironment env{300}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QTJAMBI_TRY {
                if (jobject __java_this = getJavaObjectLocalRef(env)) {
                    jdouble __java_return_value = env->CallDoubleMethod(__java_this, method_id, progress0);
                    JavaException::check(env QTJAMBI_STACKTRACEINFO );
                    qreal __qt_return_value_tmp = static_cast<qreal>(__java_return_value);
                    __qt_return_value = __qt_return_value_tmp;
                }
            } QTJAMBI_CATCH(const JavaException& exn) {
                __qj_exnhandler.handle(env, exn, "QEasingCurve::EasingFunction");
            } QTJAMBI_TRY_END
        }
    }
    return __qt_return_value;
}

void QEasingCurve_EasingFunction_shell::getFunctional(JNIEnv *env, void* result)
{
        jobject __this = QEasingCurve_EasingFunction_shell::__shell()->getJavaObjectLocalRef(env);
        uint hash = QtJambiAPI::getJavaObjectIdentity(env, __this);
        *reinterpret_cast<QEasingCurve::EasingFunction*>(result) = qtjambi_function_pointer<14,qreal(qreal)>(Functor(*this), hash, &m_functionPointerDeleter, reverseFunctionGetter ? nullptr : &reverseFunctionGetter);
}

jobject QEasingCurve_EasingFunction_shell::resolveFunctional(JNIEnv * env, const void* functionPtr, bool* ok)
{
    if(functionPtr && reverseFunctionGetter){
        const QEasingCurve::EasingFunction& function = *reinterpret_cast<const QEasingCurve::EasingFunction*>(functionPtr);
        if(const QEasingCurve_EasingFunction_shell::Functor* functor = reverseFunctionGetter(function)){
            if(ok)
                *ok = true;
            return functor->getJavaObjectLocalRef(env);
        }
        if(ok)
            *ok = !function;
    }
    return nullptr;
}

extern "C" Q_DECL_EXPORT jdouble JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QEasingCurve_00024EasingFunction_00024Impl_00024ConcreteWrapper_applyAsDouble__D)
(JNIEnv *__jni_env, jobject __this, jdouble progress0)
{
    QTJAMBI_NATIVE_METHOD_CALL("EasingFunction(...)")
    QtJambiScope __qtjambi_scope(__jni_env, __this);
    Q_UNUSED(__qtjambi_scope)
    jdouble __java_return_value{0};
    QTJAMBI_TRY {
        QEasingCurve::EasingFunction* function = QtJambiAPI::convertJavaInterfaceToNative<QEasingCurve::EasingFunction>(__jni_env, __this);
        QtJambiAPI::checkNullPointer(__jni_env, function);
        qreal  __qt_return_value = (*function)(static_cast<qreal>(progress0));
        __java_return_value = jdouble(__qt_return_value);
    } QTJAMBI_CATCH(const JavaException& exn) {
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QEasingCurve_00024EasingFunction_00024Impl_initialize_1native)
(JNIEnv *__jni_env, jclass __jni_class, jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QEasingCurve_EasingFunction_shell")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QEasingCurve_EasingFunction, sizeof(QEasingCurve_EasingFunction_shell), typeid(QEasingCurve::EasingFunction), &deleter_QEasingCurve_EasingFunction);
    } QTJAMBI_CATCH(const JavaException& exn) {
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
}

std::function<const QEasingCurve_EasingFunction_shell::Functor*(QEasingCurve::EasingFunction)> QEasingCurve_EasingFunction_shell::reverseFunctionGetter = std::function<const QEasingCurve_EasingFunction_shell::Functor*(QEasingCurve::EasingFunction)>();

void initialize_meta_info_QEasingCurve_EasingFunction(){
    using namespace RegistryAPI;
    registerFunctionalTypeInfo<QEasingCurve::EasingFunction, QEasingCurve_EasingFunction_shell>("QEasingCurve::EasingFunction", "io/qt/core/QEasingCurve$EasingFunction",
                              &deleter_QEasingCurve_EasingFunction,
                              &__qt_destruct_QEasingCurve_EasingFunction,
                              {ConstructorInfo(&__qt_construct_QEasingCurve_EasingFunction, nullptr)},
                              {FunctionInfo("applyAsDouble", "(D)D", FunctionInfo::Abstract)});
}

#endif // QT_CONFIG(easingcurve)

==> qtjambi-debuginfo-macos-6.7.2.jar: sources/QtJambiCore/QEasingCurve_EasingFunction_shell.cpp <==
#include "QEasingCurve_EasingFunction_shell.h"
#include <QtJambi/RegistryAPI>
#include <QtJambi/FunctionPointer>
#include <QtJambi/Cast>

#if QT_CONFIG(easingcurve)

// emitting (writeShellConstructor)
void deleter_QEasingCurve_EasingFunction(void *ptr,bool) { delete reinterpret_cast<QEasingCurve_EasingFunction_shell*>(ptr); }


QEasingCurve_EasingFunction_shell::QEasingCurve_EasingFunction_shell()
    : FunctionalBase()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QEasingCurve_EasingFunction_shell::QEasingCurve_EasingFunction_shell()", this)
    QEasingCurve_EasingFunction_shell::__shell()->constructed(typeid(QEasingCurve::EasingFunction));
}

// emitting (writeShellDestructor)
QEasingCurve_EasingFunction_shell::~QEasingCurve_EasingFunction_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QEasingCurve_EasingFunction_shell::~QEasingCurve_EasingFunction_shell()", this)
    if(m_functionPointerDeleter)
        m_functionPointerDeleter();
    QEasingCurve_EasingFunction_shell::__shell()->destructed(typeid(QEasingCurve::EasingFunction));
}

// construct QEasingCurve_EasingFunction_shell
void __qt_construct_QEasingCurve_EasingFunction(void* __qtjambi_ptr, JNIEnv*, jobject, jvalue*, bool, bool, bool)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QEasingCurve::EasingFunction")
    new (__qtjambi_ptr) QEasingCurve_EasingFunction_shell();
}
// destruct QEasingCurve_EasingFunction_shell
void __qt_destruct_QEasingCurve_EasingFunction(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QEasingCurve::EasingFunction")
    reinterpret_cast<QEasingCurve_EasingFunction_shell*>(ptr)->~QEasingCurve_EasingFunction_shell();
}

void QEasingCurve_EasingFunction_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QEasingCurve_EasingFunction_shell*>(ptr)->QEasingCurve_EasingFunction_shell::__shell()->tryDeleteShell(typeid(QEasingCurve::EasingFunction));
}

QtJambiShell* QEasingCurve_EasingFunction_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QEasingCurve_EasingFunction_shell) ); }

QEasingCurve_EasingFunction_shell::Functor::Functor(QEasingCurve_EasingFunction_shell& functional) : FunctorBase(typeid(QEasingCurve::EasingFunction), functional) {}

QEasingCurve_EasingFunction_shell::Functor::Functor(const Functor& functor) : FunctorBase(functor) {}

QEasingCurve_EasingFunction_shell::Functor::~Functor() {}

qreal  QEasingCurve_EasingFunction_shell::Functor::operator()(qreal progress0)
{
    qreal __qt_return_value = 0.0;
    if (jmethodID method_id = javaMethod()) {
        if (JniEnvironmentExceptionHandler env{300}) {
            QTJAMBI_TRY {
                if (jobject __java_this = getJavaObjectLocalRef(env)) {
                    jdouble __java_return_value = env->CallDoubleMethod(__java_this, method_id, progress0);
                    JavaException::check(env QTJAMBI_STACKTRACEINFO );
                    qreal __qt_return_value_tmp = static_cast<qreal>(__java_return_value);
                    __qt_return_value = __qt_return_value_tmp;
                }
            } QTJAMBI_CATCH(const JavaException& exn) {
                env.handleException(exn, "QEasingCurve::EasingFunction");
            } QTJAMBI_TRY_END
        }
    }
    return __qt_return_value;
}

void QEasingCurve_EasingFunction_shell::getFunctional(JNIEnv *env, void* result)
{
        jobject __this = QEasingCurve_EasingFunction_shell::__shell()->getJavaObjectLocalRef(env);
        uint hash = QtJambiAPI::getJavaObjectIdentity(env, __this);
        *reinterpret_cast<QEasingCurve::EasingFunction*>(result) = qtjambi_function_pointer<14,qreal(qreal)>(Functor(*this), hash, &m_functionPointerDeleter, reverseFunctionGetter ? nullptr : &reverseFunctionGetter);
}

jobject QEasingCurve_EasingFunction_shell::resolveFunctional(JNIEnv * env, const void* functionPtr, bool* ok)
{
    if(functionPtr && reverseFunctionGetter){
        const QEasingCurve::EasingFunction& function = *reinterpret_cast<const QEasingCurve::EasingFunction*>(functionPtr);
        if(const QEasingCurve_EasingFunction_shell::Functor* functor = reverseFunctionGetter(function)){
            if(ok)
                *ok = true;
            return functor->getJavaObjectLocalRef(env);
        }
        if(ok)
            *ok = !function;
    }
    return nullptr;
}

extern "C" Q_DECL_EXPORT jdouble JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QEasingCurve_00024EasingFunction_00024Impl_00024ConcreteWrapper_applyAsDouble__D)
(JNIEnv *__jni_env, jobject __this, jdouble progress0)
{
    QTJAMBI_NATIVE_METHOD_CALL("EasingFunction(...)")
    jdouble __java_return_value{0};
    QTJAMBI_TRY {
        QEasingCurve::EasingFunction* function = QtJambiAPI::convertJavaInterfaceToNative<QEasingCurve::EasingFunction>(__jni_env, __this);
        QtJambiAPI::checkNullPointer(__jni_env, function);
        qreal  __qt_return_value = (*function)(static_cast<qreal>(progress0));
        __java_return_value = jdouble(__qt_return_value);
    } QTJAMBI_CATCH(const JavaException& exn) {
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QEasingCurve_00024EasingFunction_00024Impl_initialize_1native)
(JNIEnv *__jni_env, jclass __jni_class, jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QEasingCurve_EasingFunction_shell")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QEasingCurve_EasingFunction, sizeof(QEasingCurve_EasingFunction_shell), typeid(QEasingCurve::EasingFunction), 0, &deleter_QEasingCurve_EasingFunction);
    } QTJAMBI_CATCH(const JavaException& exn) {
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
}

std::function<const QEasingCurve_EasingFunction_shell::Functor*(QEasingCurve::EasingFunction)> QEasingCurve_EasingFunction_shell::reverseFunctionGetter = std::function<const QEasingCurve_EasingFunction_shell::Functor*(QEasingCurve::EasingFunction)>();

void initialize_meta_info_QEasingCurve_EasingFunction(){
    using namespace RegistryAPI;
    registerFunctionalTypeInfo<QEasingCurve::EasingFunction, QEasingCurve_EasingFunction_shell>("QEasingCurve::EasingFunction", "io/qt/core/QEasingCurve$EasingFunction",
                              false,
                              &deleter_QEasingCurve_EasingFunction,
                              &__qt_destruct_QEasingCurve_EasingFunction,
                              {ConstructorInfo(&__qt_construct_QEasingCurve_EasingFunction, nullptr)},
                              {FunctionInfo("applyAsDouble", "(D)D", FunctionInfo::Abstract)});
}

#endif // QT_CONFIG(easingcurve)
